Module fingerer
cuqueclicker_
lib
1.2.1
Module fingerer
Module Items
Structs
Constants
Functions
In cuqueclicker_
lib::
game
cuqueclicker_lib
::
game
Module
fingerer
Structs

Fingerer
Stats
Constants

FINGERERS
Functions

count
visible
Whether a fingerer should be visible in the sidebar. Show when the player either already owns one, or their lifetime_cuques has reached half the base cost (so they can see what’s coming).